/****************************************************************************
** GUI meta object code from reading C++ file 'gui.h'
**
** Created: Sat Jan 6 23:56:09 2007
**      by: The Qt MOC ($Id: qt/moc_yacc.cpp   3.3.6   edited Mar 8 17:43 $)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#undef QT_NO_COMPAT
#include "gui.h"
#include <qmetaobject.h>
#include <qapplication.h>

#include <private/qucomextra_p.h>
#if !defined(Q_MOC_OUTPUT_REVISION) || (Q_MOC_OUTPUT_REVISION != 26)
#error "This file was generated using the moc from 3.3.6. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

const char *GUI::className() const
{
    return "GUI";
}

QMetaObject *GUI::metaObj = 0;
static QMetaObjectCleanUp cleanUp_GUI( "GUI", &GUI::staticMetaObject );

#ifndef QT_NO_TRANSLATION
QString GUI::tr( const char *s, const char *c )
{
    if ( qApp )
	return qApp->translate( "GUI", s, c, QApplication::DefaultCodec );
    else
	return QString::fromLatin1( s );
}
#ifndef QT_NO_TRANSLATION_UTF8
QString GUI::trUtf8( const char *s, const char *c )
{
    if ( qApp )
	return qApp->translate( "GUI", s, c, QApplication::UnicodeUTF8 );
    else
	return QString::fromUtf8( s );
}
#endif // QT_NO_TRANSLATION_UTF8

#endif // QT_NO_TRANSLATION

QMetaObject* GUI::staticMetaObject()
{
    if ( metaObj )
	return metaObj;
    QMetaObject* parentObject = QMainWindow::staticMetaObject();
    static const QUParameter param_slot_0[] = {
	{ 0, &static_QUType_bool, 0, QUParameter::In }
    };
    static const QUMethod slot_0 = {"slot_setConnectionState", 1, param_slot_0 };
    static const QUMethod slot_1 = {"slot_WELCOME", 0, 0 };
    static const QUMethod slot_2 = {"slot_connectToDB", 0, 0 };
    static const QUMethod slot_3 = {"slot_disconnectFromDB", 0, 0 };
    static const QUMethod slot_4 = {"slot_connectToMixxx", 0, 0 };
    static const QUMethod slot_5 = {"slot_disconnectFromMixxx", 0, 0 };
    static const QUMethod slot_6 = {"slot_QUIT", 0, 0 };
    static const QUMethod slot_7 = {"slot_PREF", 0, 0 };
    static const QUMethod slot_8 = {"slot_CREATEDB", 0, 0 };
    static const QUMethod slot_9 = {"slot_INITDB", 0, 0 };
    static const QUMethod slot_10 = {"slot_ABOUT", 0, 0 };
    static const QUMethod slot_11 = {"slot_DOCUMENTATION", 0, 0 };
    static const QUMethod slot_12 = {"slot_selectAll", 0, 0 };
    static const QUMethod slot_13 = {"slot_unselectAll", 0, 0 };
    static const QUMethod slot_14 = {"slot_pause", 0, 0 };
    static const QUMethod slot_15 = {"slot_stop", 0, 0 };
    static const QUMethod slot_16 = {"slot_next", 0, 0 };
    static const QUMethod slot_17 = {"slot_prev", 0, 0 };
    static const QUMethod slot_18 = {"slot_prepause", 0, 0 };
    static const QUMethod slot_19 = {"slot_prestop", 0, 0 };
    static const QUMethod slot_20 = {"slot_prenext", 0, 0 };
    static const QUMethod slot_21 = {"slot_preprev", 0, 0 };
    static const QUMethod slot_22 = {"slot_MEXTRAS_LOG", 0, 0 };
    static const QUMethod slot_23 = {"slot_MEXTRAS_SCAN", 0, 0 };
    static const QUMethod slot_24 = {"slot_MEXTRAS_ABORT", 0, 0 };
    static const QUMethod slot_25 = {"slot_MEXTRAS_ZAP", 0, 0 };
    static const QUMethod slot_26 = {"slot_MEXTRAS_VERSION", 0, 0 };
    static const QUMethod slot_27 = {"slot_MEXTRAS_PLUGINS", 0, 0 };
    static const QUMethod slot_28 = {"slot_MEXTRAS_UPDATE", 0, 0 };
    static const QUParameter param_slot_29[] = {
	{ 0, &static_QUType_bool, 0, QUParameter::In }
    };
    static const QUMethod slot_29 = {"slot_toggleleft", 1, param_slot_29 };
    static const QUParameter param_slot_30[] = {
	{ 0, &static_QUType_bool, 0, QUParameter::In }
    };
    static const QUMethod slot_30 = {"slot_togglebottom", 1, param_slot_30 };
    static const QUParameter param_slot_31[] = {
	{ 0, &static_QUType_bool, 0, QUParameter::In }
    };
    static const QUMethod slot_31 = {"slot_toggleright", 1, param_slot_31 };
    static const QUMethod slot_32 = {"polish", 0, 0 };
    static const QMetaData slot_tbl[] = {
	{ "slot_setConnectionState(bool)", &slot_0, QMetaData::Public },
	{ "slot_WELCOME()", &slot_1, QMetaData::Public },
	{ "slot_connectToDB()", &slot_2, QMetaData::Private },
	{ "slot_disconnectFromDB()", &slot_3, QMetaData::Private },
	{ "slot_connectToMixxx()", &slot_4, QMetaData::Private },
	{ "slot_disconnectFromMixxx()", &slot_5, QMetaData::Private },
	{ "slot_QUIT()", &slot_6, QMetaData::Private },
	{ "slot_PREF()", &slot_7, QMetaData::Private },
	{ "slot_CREATEDB()", &slot_8, QMetaData::Private },
	{ "slot_INITDB()", &slot_9, QMetaData::Private },
	{ "slot_ABOUT()", &slot_10, QMetaData::Private },
	{ "slot_DOCUMENTATION()", &slot_11, QMetaData::Private },
	{ "slot_selectAll()", &slot_12, QMetaData::Private },
	{ "slot_unselectAll()", &slot_13, QMetaData::Private },
	{ "slot_pause()", &slot_14, QMetaData::Private },
	{ "slot_stop()", &slot_15, QMetaData::Private },
	{ "slot_next()", &slot_16, QMetaData::Private },
	{ "slot_prev()", &slot_17, QMetaData::Private },
	{ "slot_prepause()", &slot_18, QMetaData::Private },
	{ "slot_prestop()", &slot_19, QMetaData::Private },
	{ "slot_prenext()", &slot_20, QMetaData::Private },
	{ "slot_preprev()", &slot_21, QMetaData::Private },
	{ "slot_MEXTRAS_LOG()", &slot_22, QMetaData::Private },
	{ "slot_MEXTRAS_SCAN()", &slot_23, QMetaData::Private },
	{ "slot_MEXTRAS_ABORT()", &slot_24, QMetaData::Private },
	{ "slot_MEXTRAS_ZAP()", &slot_25, QMetaData::Private },
	{ "slot_MEXTRAS_VERSION()", &slot_26, QMetaData::Private },
	{ "slot_MEXTRAS_PLUGINS()", &slot_27, QMetaData::Private },
	{ "slot_MEXTRAS_UPDATE()", &slot_28, QMetaData::Private },
	{ "slot_toggleleft(bool)", &slot_29, QMetaData::Private },
	{ "slot_togglebottom(bool)", &slot_30, QMetaData::Private },
	{ "slot_toggleright(bool)", &slot_31, QMetaData::Private },
	{ "polish()", &slot_32, QMetaData::Private }
    };
    metaObj = QMetaObject::new_metaobject(
	"GUI", parentObject,
	slot_tbl, 33,
	0, 0,
#ifndef QT_NO_PROPERTIES
	0, 0,
	0, 0,
#endif // QT_NO_PROPERTIES
	0, 0 );
    cleanUp_GUI.setMetaObject( metaObj );
    return metaObj;
}

void* GUI::qt_cast( const char* clname )
{
    if ( !qstrcmp( clname, "GUI" ) )
	return this;
    return QMainWindow::qt_cast( clname );
}

bool GUI::qt_invoke( int _id, QUObject* _o )
{
    switch ( _id - staticMetaObject()->slotOffset() ) {
    case 0: slot_setConnectionState((bool)static_QUType_bool.get(_o+1)); break;
    case 1: slot_WELCOME(); break;
    case 2: slot_connectToDB(); break;
    case 3: slot_disconnectFromDB(); break;
    case 4: slot_connectToMixxx(); break;
    case 5: slot_disconnectFromMixxx(); break;
    case 6: slot_QUIT(); break;
    case 7: slot_PREF(); break;
    case 8: slot_CREATEDB(); break;
    case 9: slot_INITDB(); break;
    case 10: slot_ABOUT(); break;
    case 11: slot_DOCUMENTATION(); break;
    case 12: slot_selectAll(); break;
    case 13: slot_unselectAll(); break;
    case 14: slot_pause(); break;
    case 15: slot_stop(); break;
    case 16: slot_next(); break;
    case 17: slot_prev(); break;
    case 18: slot_prepause(); break;
    case 19: slot_prestop(); break;
    case 20: slot_prenext(); break;
    case 21: slot_preprev(); break;
    case 22: slot_MEXTRAS_LOG(); break;
    case 23: slot_MEXTRAS_SCAN(); break;
    case 24: slot_MEXTRAS_ABORT(); break;
    case 25: slot_MEXTRAS_ZAP(); break;
    case 26: slot_MEXTRAS_VERSION(); break;
    case 27: slot_MEXTRAS_PLUGINS(); break;
    case 28: slot_MEXTRAS_UPDATE(); break;
    case 29: slot_toggleleft((bool)static_QUType_bool.get(_o+1)); break;
    case 30: slot_togglebottom((bool)static_QUType_bool.get(_o+1)); break;
    case 31: slot_toggleright((bool)static_QUType_bool.get(_o+1)); break;
    case 32: polish(); break;
    default:
	return QMainWindow::qt_invoke( _id, _o );
    }
    return TRUE;
}

bool GUI::qt_emit( int _id, QUObject* _o )
{
    return QMainWindow::qt_emit(_id,_o);
}
#ifndef QT_NO_PROPERTIES

bool GUI::qt_property( int id, int f, QVariant* v)
{
    return QMainWindow::qt_property( id, f, v);
}

bool GUI::qt_static_property( QObject* , int , int , QVariant* ){ return FALSE; }
#endif // QT_NO_PROPERTIES
